class EnvChoices:
    NORMAL = "normal"
    E2E = 'e2e'
    TEST = 'test'
    
class ResponseChoices:
    success = "success"
    already_exists = "already exists"
    does_not_exist = "does not exist"
    same_object = "same object"
    not_logged = "not logged"
    not_allowed = "not allowed"
    different_type = "different type"
    not_balanced = "not balanced"
    failure = "failure"
    not_valid = "not valid"
    limit_exceeded = "limit exceeded"